==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPivotDimensionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebPivotDimensionDescription } from "./WebPivotDimensionDescription";
/**
 * @hidden
 */
export let WebPivotDimensionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDimensionDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDimensionDescriptionMetadata.a == null) {
                WebPivotDimensionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDimensionDescriptionMetadata.c(WebPivotDimensionDescriptionMetadata.a);
            }
            if (a.k(WebPivotDimensionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPivotDimensionDescriptionMetadata.a);
            WebPivotDimensionDescriptionMetadata.d(a);
            WebFilteringExpressionsTreeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDimension");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("ChildLevel", "ExportedType:WebPivotDimension");
            a.item("MemberName", "String");
            a.item("Enabled", "Boolean");
            a.item("Filter", "ExportedType:WebFilteringExpressionsTree");
            a.item("SortDirection", "ExportedType:string:SortingDirection");
            a.item("SortDirection@names", "None;Asc;Desc");
            a.item("DataType", "ExportedType:string:GridColumnDataType");
            a.item("DataType@stringUnion", "WebComponents;React");
            a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
            a.item("Width", "String");
            a.item("Level", "Number:double");
            a.item("MemberFunctionRef", "EventRef::memberFunction");
        }
        static d(a) {
            WebPivotDimensionDescriptionMetadata.b(a);
            a.ac("WebPivotDimension", () => new WebPivotDimensionDescription());
            a.ab("WebPivotDimension", WebPivotDimensionDescriptionMetadata.a);
        }
    }
    WebPivotDimensionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotDimensionDescriptionMetadata, 'WebPivotDimensionDescriptionMetadata');
    WebPivotDimensionDescriptionMetadata.a = null;
    return WebPivotDimensionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebPivotDimensionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebPivotDimensionDescription } from "./WebPivotDimensionDescription";
/**
 * @hidden
 */
export let WebPivotDimensionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDimensionDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDimensionDescriptionMetadata.a == null) {
                WebPivotDimensionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDimensionDescriptionMetadata.c(WebPivotDimensionDescriptionMetadata.a);
            }
            if (a.k(WebPivotDimensionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotDimensionDescriptionMetadata.a);
            WebPivotDimensionDescriptionMetadata.d(a);
            WebFilteringExpressionsTreeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDimension");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("ChildLevel", "ExportedType:WebPivotDimension");
            a.item("MemberName", "String");
            a.item("DisplayName", "String");
            a.item("Enabled", "Boolean");
            a.item("Filter", "ExportedType:WebFilteringExpressionsTree");
            a.item("Sortable", "Boolean");
            a.item("SortDirection", "ExportedType:string:SortingDirection");
            a.item("SortDirection@names", "None;Asc;Desc");
            a.item("DataType", "ExportedType:string:GridColumnDataType");
            a.item("DataType@stringUnion", "WebComponents;React");
            a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
            a.item("Width", "String");
            a.item("Level", "Number:double");
            a.item("HorizontalSummary", "Boolean");
            a.item("MemberFunctionRef", "EventRef::memberFunction");
        }
        static d(a) {
            WebPivotDimensionDescriptionMetadata.b(a);
            a.ae("WebPivotDimension", () => new WebPivotDimensionDescription());
            a.ad("WebPivotDimension", WebPivotDimensionDescriptionMetadata.a);
        }
    }
    WebPivotDimensionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotDimensionDescriptionMetadata, 'WebPivotDimensionDescriptionMetadata');
    WebPivotDimensionDescriptionMetadata.a = null;
    return WebPivotDimensionDescriptionMetadata;
})();
